PackageBuilder

Struct PackageBuilder 

pub struct PackageBuilder { /* private fields */ }
Deterministic writer for the .aion ZIP container format.

Implementations

Source

impl PackageBuilder

pub fn new(manifest: Manifest, beams: BeamSet) -> Self

Creates a builder without source files.

pub fn with_source<I, N, B>( manifest: Manifest, beams: BeamSet, source: I, ) -> Self
where I: IntoIterator<Item = (N, B)>, N: Into<String>, B: Into<Vec<u8>>,

Creates a builder with optional source files keyed by logical module name.

pub fn finalise_manifest(&self) -> Result<Manifest, PackageError>

Returns the manifest after stamping the authoritative beam content hash.

Errors

Returns PackageError::MissingEntryModule when the manifest entry module is not present in the supplied beam set.

pub fn write_to_bytes(&self) -> Result<Vec<u8>, PackageError>

Writes a deterministic .aion archive into memory.

Errors

Returns PackageError variants for missing entry modules, manifest JSON serialisation failures, ZIP writer failures, or target I/O failures.

pub fn write_to_path(&self, path: impl AsRef<Path>) -> Result<(), PackageError>

Writes a deterministic .aion archive to the supplied filesystem path.

Errors

Returns PackageError variants for missing entry modules, manifest JSON serialisation failures, ZIP writer failures, or target I/O failures.