pub struct ParsedDeployedName { /* private fields */ }Expand description
A deployed module name parsed into its logical module name and content hash.
Implementations
Sourceimpl ParsedDeployedName
impl ParsedDeployedName
Sourcepub fn new(logical: String, hash: ContentHash) -> Self
pub fn new(logical: String, hash: ContentHash) -> Self
Creates a parsed deployed-name value from its two components.
Sourcepub fn logical(&self) -> &str
pub fn logical(&self) -> &str
Returns the logical module name before deployment-time namespacing.
Sourcepub const fn hash(&self) -> &ContentHash
pub const fn hash(&self) -> &ContentHash
Returns the content hash embedded in the deployed module name.
Sourcepub fn into_parts(self) -> (String, ContentHash)
pub fn into_parts(self) -> (String, ContentHash)
Consumes the parsed value into its owned components.