pub enum ExcludedReason {
SdkTestOnly,
DevDependency,
}Expand description
Reason a discovered compiled module was excluded from packaging.
Variants
SdkTestOnly
SDK test machinery from the aion_flow package’s ebin.
DevDependency
Module of a package outside the production dependency closure.