pub struct PackageBuilder { /* private fields */ }Expand description
Deterministic writer for the .aion ZIP container format.
Implementations
Sourceimpl PackageBuilder
impl PackageBuilder
Sourcepub fn with_source<I, N, B>(
manifest: Manifest,
beams: BeamSet,
source: I,
) -> Self
pub fn with_source<I, N, B>( manifest: Manifest, beams: BeamSet, source: I, ) -> Self
Creates a builder with optional source files keyed by logical module name.
Sourcepub fn finalise_manifest(&self) -> Result<Manifest, PackageError>
pub fn finalise_manifest(&self) -> Result<Manifest, PackageError>
Returns the manifest after stamping the authoritative beam content hash.
Errors
Returns PackageError::MissingEntryModule when the manifest entry module
is not present in the supplied beam set.
Sourcepub fn write_to_bytes(&self) -> Result<Vec<u8>, PackageError>
pub fn write_to_bytes(&self) -> Result<Vec<u8>, PackageError>
Writes a deterministic .aion archive into memory.
Errors
Returns PackageError variants for missing entry modules, manifest JSON
serialisation failures, ZIP writer failures, or target I/O failures.
Sourcepub fn write_to_path(&self, path: impl AsRef<Path>) -> Result<(), PackageError>
pub fn write_to_path(&self, path: impl AsRef<Path>) -> Result<(), PackageError>
Writes a deterministic .aion archive to the supplied filesystem path.
Errors
Returns PackageError variants for missing entry modules, manifest JSON
serialisation failures, ZIP writer failures, or target I/O failures.